# 25 "src/kernel_internals/parsing/logic_lexer.mll"
 

  open Logic_parser
  open Lexing

  type state = Normal | Test

  let state_stack = Stack.create ()

  let () = Stack.push Normal state_stack

  let get_state () = try Stack.top state_stack with Stack.Empty -> Normal

  let pop_state () = try ignore (Stack.pop state_stack) with Stack.Empty -> ()

  exception Error of (int * int) * string

  let loc lexbuf = (lexeme_start lexbuf, lexeme_end lexbuf)

  let lex_error lexbuf s =
    raise (Error (loc lexbuf, "lexical error, " ^ s))

  let find_utf8 =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [ Utf8_logic.forall, FORALL;
        Utf8_logic.exists, EXISTS;
        Utf8_logic.eq, EQ;
        Utf8_logic.neq, NE;
        Utf8_logic.le, LE;
        Utf8_logic.ge, GE;
        Utf8_logic.implies,IMPLIES;
        Utf8_logic.iff, IFF;
        Utf8_logic.conj, AND;
        Utf8_logic.disj, OR;
        Utf8_logic.neg, NOT;
        Utf8_logic.x_or, HATHAT;
        Utf8_logic.minus, MINUS;
        Utf8_logic.boolean, BOOLEAN;
        Utf8_logic.integer, INTEGER;
        Utf8_logic.real, REAL;
        Utf8_logic.inset, IN;
        Utf8_logic.pi, PI;
      ];

    fun s -> try Hashtbl.find h s
    with Not_found -> IDENTIFIER s

  let all_digits s =
    let is_digit =
      function
      | '0'..'9' | 'a'..'f' | 'A'..'F' -> ()
      | _ -> raise Exit
    in
    try String.iter is_digit s; true with Exit -> false

  let is_ucn s =
    if String.length s <= 2 || s.[0] <> '\\' then false else begin
      match s.[1] with
      | 'U' -> String.length s = 10 && all_digits (String.sub s 2 8)
      | 'u' -> String.length s = 6 && all_digits (String.sub s 2 4)
      | _ -> false
    end

  let int_of_digit chr =
    match chr with
    | '0'..'9' -> (Char.code chr) - (Char.code '0')
    | 'a'..'f' -> (Char.code chr) - (Char.code 'a') + 10
    | 'A'..'F' -> (Char.code chr) - (Char.code 'A') + 10
    | _ -> assert false

  (* assumes is_ucn s *)
  let unicode_char s =
    let code = ref 0 in
    let add_digit c = code := 16 * !code + int_of_digit c in
    String.iter add_digit (String.sub s 2 (String.length s - 2));
    let c = Utf8_logic.from_unichar !code in
    find_utf8 c

  let identifier, is_acsl_keyword =
    let all_kw = Hashtbl.create 37 in
    let c_kw = Hashtbl.create 37 in
    let type_kw = Hashtbl.create 3 in
    List.iter
      (fun (i,t,flag) ->
         Hashtbl.add all_kw i t;
         if flag then Hashtbl.add c_kw i t
      )
      [
        "admit", (fun _ -> ADMIT), false;
        "allocates", (fun _ -> ALLOCATES), false;
        "assert", (fun _ -> ASSERT), false;
        "assigns", (fun _ -> ASSIGNS), false;
        "assumes", (fun _ -> ASSUMES), false;
        "at", (fun _ -> EXT_AT), false;
        (* ACSL extension for external spec file *)
        "axiom", (fun _ -> AXIOM), false;
        "axiomatic", (fun _ -> AXIOMATIC), false;
        "behavior", (fun _ -> BEHAVIOR), false;
        "behaviors", (fun _ -> BEHAVIORS), false;
        "_Bool", (fun _ -> BOOL), true;
        "breaks", (fun _ -> BREAKS), false;
        "case", (fun _ -> CASE), true;
        "char", (fun _ -> CHAR), true;
        "check", (fun _ -> CHECK), false;
        "complete", (fun _ -> COMPLETE), false;
        "const", (fun _ -> CONST), true;
        "continues", (fun _ -> CONTINUES), false;
        "contract", (fun _ -> CONTRACT), false;
        (* ACSL extension for external spec file *)
        "decreases", (fun _ -> DECREASES), false;
        "disjoint", (fun _ -> DISJOINT), false;
        "double", (fun _ -> DOUBLE), true;
        "else", (fun _ -> ELSE), true;
        "ensures", (fun _ -> ENSURES), false ;
        "enum", (fun _ -> ENUM), true;
        "exits", (fun _ -> EXITS), false;
        "frees", (fun _ -> FREES), false;
        "function", (fun _ -> FUNCTION), false;
        (* ACSL extension for external spec file *)
        "float", (fun _ -> FLOAT), true;
        "for", (fun _ -> FOR), true;
        "global", (fun _ -> GLOBAL), false;
        "if", (fun _ -> IF), true;
	"impact", (fun _ -> IMPACT), false;
	"inductive", (fun _ -> INDUCTIVE), false;
	"include", (fun _ -> INCLUDE), false;
        (* ACSL extension for external spec file *)
        "int", (fun _ -> INT), true;
        "invariant", (fun _ -> INVARIANT), false;
        "label", (fun _ -> LABEL), false;
        "lemma", (fun _ -> LEMMA), false;
        "let", (fun _ -> EXT_LET), false;
        (* ACSL extension for external spec file *)
        "logic", (fun _ -> LOGIC), false;
        "long", (fun _ -> LONG), true;
        "loop", (fun _ -> LOOP), false;
        "model", (fun _ -> MODEL), false;
        (* ACSL extension for model fields *)
        "module", (fun _ -> MODULE), false;
        (* ACSL extension for external spec file *)
        "pragma", (fun _ -> PRAGMA), false;
        "predicate", (fun _ -> PREDICATE), false;
        "reads", (fun _ -> READS), true;
        (* treated specifically in the parser to
           avoid issue in volatile clause. *)
        "requires", (fun _ -> REQUIRES), false;
        "returns", (fun _ -> RETURNS), false;
        "short", (fun _ -> SHORT), true;
        "signed", (fun _ -> SIGNED), true;
        "sizeof", (fun _ -> SIZEOF), true;
        "slice", (fun _ -> SLICE), false;
        "struct", (fun _ -> STRUCT), true;
        "terminates", (fun _ -> TERMINATES), false;
        "type", (fun _ -> TYPE), false;
        "union", (fun _ -> UNION), true;
        "unsigned", (fun _ -> UNSIGNED), true;
        "variant", (fun _ -> VARIANT), false;
        "void", (fun _ -> VOID), true;
        "volatile", (fun _ -> VOLATILE), true;
        "writes", (fun _ -> WRITES), true;
        (* treated specifically in the parser to
           avoid issue in volatile clause. *)
        "__FC_FILENAME__",
        (fun loc ->
           let filename =
             Filepath.(Normalized.to_pretty_string (fst loc).pos_path)
           in
           STRING_LITERAL (false,filename)),
        true;
      ];
    List.iter (fun (x, y) -> Hashtbl.add type_kw x y)
      ["integer", INTEGER; "real", REAL; "boolean", BOOLEAN; ];
    (fun s loc ->
      try
        (Hashtbl.find (if Logic_utils.is_kw_c_mode () then c_kw else all_kw) s)
        loc
      with Not_found ->
        let res =
          if not (Logic_utils.is_kw_c_mode ()) then begin
            match Logic_env.extension_category s with
            | exception Not_found -> None
            | Cil_types.Ext_contract -> Some (EXT_CONTRACT s)
            | Cil_types.Ext_global ->
              begin
                match Logic_env.is_extension_block s with
                | false -> Some (EXT_GLOBAL s)
                | true -> Some (EXT_GLOBAL_BLOCK s)
              end
            | Cil_types.Ext_code_annot _ -> Some (EXT_CODE_ANNOT s)
          end
          else None
        in
        match res with
        | None ->
        if Logic_env.typename_status s then TYPENAME s
        else
          (try
             Hashtbl.find type_kw s
           with Not_found ->
             if Logic_utils.is_rt_type_mode () then TYPENAME s
               else IDENTIFIER s)
        | Some lex -> lex
    ),
    (fun s -> Hashtbl.mem all_kw s || Hashtbl.mem type_kw s)

  let bs_identifier =
    let h = Hashtbl.create 97 in
    List.iter (fun (i,t) -> Hashtbl.add h i t)
      [
        "\\allocation", ALLOCATION;
        "\\allocable", ALLOCABLE;
        "\\automatic", AUTOMATIC;
        "\\at", AT;
        "\\base_addr", BASE_ADDR;
        "\\block_length", BLOCK_LENGTH;
        "\\dynamic", DYNAMIC;
        "\\empty", EMPTY;
        "\\exists", EXISTS;
        "\\false", FALSE;
        "\\forall", FORALL;
        "\\freeable", FREEABLE;
        "\\fresh", FRESH;
        "\\from", FROM;
        "\\initialized", INITIALIZED;
        "\\dangling", DANGLING;
        "\\in", IN;
        "\\inter", INTER;
        "\\lambda", LAMBDA;
        "\\let", LET;
        "\\nothing", NOTHING;
        "\\null", NULL;
        "\\offset", OFFSET;
        "\\old", OLD;
        "\\pi", PI;
        "\\register", REGISTER;
        "\\result", RESULT;
        "\\separated", SEPARATED;
        "\\static", STATIC;
        "\\true", TRUE;
        "\\type", BSTYPE;
        "\\typeof", TYPEOF;
        "\\unallocated", UNALLOCATED;
        "\\union", BSUNION;
        "\\object_pointer", OBJECT_POINTER;
        "\\valid", VALID;
        "\\valid_read", VALID_READ;
        "\\valid_index", VALID_INDEX;
        "\\valid_range", VALID_RANGE;
        "\\valid_function", VALID_FUNCTION;
        "\\with", WITH;
      ];
    fun lexbuf ->
      let s = lexeme lexbuf in
      if is_ucn s then unicode_char s else begin
        try Hashtbl.find h s with Not_found ->
          if Logic_env.typename_status s then TYPENAME s
          else IDENTIFIER s
      end

  (* Update lexer buffer. *)
  let update_line_pos lexbuf line =
    let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <-
      { pos with
	Lexing.pos_lnum = line;
	Lexing.pos_bol = pos.Lexing.pos_cnum;
      }

  let update_file_pos lexbuf file =
   let pos = lexbuf.Lexing.lex_curr_p in
    lexbuf.Lexing.lex_curr_p <- { pos with Lexing.pos_fname = file }

  let accept_c_comments_into_acsl_spec = ref false

  let hack_merge_tokens current next =
    match (current,next) with
    | CHECK, REQUIRES -> true, CHECK_REQUIRES
    | CHECK, ENSURES -> true, CHECK_ENSURES
    | CHECK, EXITS -> true, CHECK_EXITS
    | CHECK, RETURNS -> true, CHECK_RETURNS
    | CHECK, BREAKS -> true, CHECK_BREAKS
    | CHECK, CONTINUES -> true, CHECK_CONTINUES
    | CHECK, LOOP -> true, CHECK_LOOP
    | CHECK, INVARIANT -> true, CHECK_INVARIANT
    | CHECK, LEMMA -> true, CHECK_LEMMA
    | ADMIT, REQUIRES -> true, ADMIT_REQUIRES
    | ADMIT, ENSURES -> true, ADMIT_ENSURES
    | ADMIT, EXITS -> true, ADMIT_EXITS
    | ADMIT, RETURNS -> true, ADMIT_RETURNS
    | ADMIT, BREAKS -> true, ADMIT_BREAKS
    | ADMIT, CONTINUES -> true, ADMIT_CONTINUES
    | ADMIT, LOOP -> true, ADMIT_LOOP
    | ADMIT, INVARIANT -> true, ADMIT_INVARIANT
    | ADMIT, LEMMA -> true, ADMIT_LEMMA
    | _ -> false, current

# 300 "src/kernel_internals/parsing/logic_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\190\255\191\255\000\000\197\255\133\000\199\255\200\255\
    \201\255\202\255\197\000\210\255\212\255\166\000\219\255\203\000\
    \226\255\227\255\229\255\230\255\201\000\170\000\226\000\220\000\
    \223\000\205\000\238\255\001\001\223\000\004\001\252\000\034\001\
    \107\001\196\001\254\001\238\000\239\000\254\255\028\001\250\255\
    \089\001\252\255\253\255\217\255\251\255\073\002\186\002\125\002\
    \091\001\126\002\242\255\239\255\092\001\153\002\182\002\246\000\
    \194\002\239\000\008\003\031\003\090\003\232\002\160\003\029\001\
    \128\003\198\003\231\003\007\004\063\003\241\255\017\004\046\004\
    \078\004\088\004\107\004\140\004\172\004\182\004\030\001\032\001\
    \033\001\201\004\211\004\240\255\233\004\243\004\016\005\026\005\
    \055\005\065\005\094\005\243\000\106\005\135\005\145\005\174\005\
    \221\255\228\000\237\255\194\255\247\000\234\000\248\000\236\255\
    \249\000\234\255\228\255\250\000\235\255\233\255\195\255\232\255\
    \203\255\224\255\215\255\193\255\206\255\196\255\231\000\251\255\
    \252\255\207\005\253\255\075\001\024\006\047\006\188\001\254\255\
    \233\005\251\255\208\000\223\005\254\255\255\255\204\000\214\000\
    \252\255\034\003\252\255\000\003\254\255\255\255\253\255\210\003\
    \211\003\118\005\133\001\253\255\254\255\255\255\124\002\252\255\
    \253\255\014\001\255\255\254\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\063\000\255\255\057\000\255\255\255\255\
    \255\255\255\255\047\000\255\255\255\255\041\000\255\255\030\000\
    \255\255\255\255\255\255\255\255\024\000\042\000\039\000\035\000\
    \046\000\051\000\255\255\065\000\032\000\065\000\011\000\011\000\
    \007\000\007\000\065\000\037\000\044\000\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\006\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\014\000\255\255\012\000\
    \010\000\255\255\255\255\255\255\008\000\255\255\255\255\008\000\
    \255\255\255\255\255\255\014\000\255\255\255\255\014\000\255\255\
    \014\000\255\255\255\255\255\255\014\000\255\255\009\000\009\000\
    \010\000\014\000\255\255\255\255\255\255\014\000\255\255\014\000\
    \255\255\014\000\255\255\033\000\014\000\255\255\014\000\255\255\
    \255\255\050\000\255\255\255\255\255\255\048\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\004\000\255\255\001\000\255\255\000\000\001\000\255\255\
    \255\255\255\255\004\000\002\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\003\000\255\255\255\255\255\255\255\255\
    \255\255\002\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\255\255\255\255";
  Lexing.lex_default =
   "\003\000\000\000\000\000\255\255\000\000\255\255\000\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\046\000\255\255\049\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \040\000\000\000\000\000\000\000\000\000\255\255\046\000\049\000\
    \049\000\049\000\000\000\000\000\046\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\255\255\255\255\255\255\000\000\
    \255\255\000\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\119\000\000\000\
    \000\000\255\255\000\000\255\255\255\255\255\255\255\255\000\000\
    \129\000\000\000\255\255\255\255\000\000\000\000\255\255\255\255\
    \000\000\138\000\000\000\143\000\000\000\000\000\000\000\143\000\
    \143\000\143\000\147\000\000\000\000\000\000\000\151\000\000\000\
    \000\000\255\255\000\000\000\000";
  Lexing.lex_trans =
   "\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\038\000\037\000\001\000\038\000\038\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
    \038\000\020\000\027\000\026\000\019\000\011\000\022\000\029\000\
    \009\000\008\000\035\000\014\000\018\000\023\000\028\000\036\000\
    \031\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\015\000\016\000\024\000\025\000\010\000\017\000\
    \038\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\033\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\005\000\034\000\004\000\013\000\032\000\
    \001\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\007\000\021\000\006\000\012\000\001\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\001\000\
    \002\000\117\000\116\000\115\000\114\000\113\000\112\000\110\000\
    \109\000\107\000\097\000\255\255\100\000\091\000\255\255\092\000\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\039\000\106\000\099\000\101\000\044\000\040\000\078\000\
    \078\000\096\000\098\000\051\000\104\000\038\000\111\000\102\000\
    \038\000\038\000\053\000\255\255\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\103\000\105\000\
    \108\000\134\000\135\000\136\000\038\000\155\000\000\000\000\000\
    \000\000\054\000\055\000\121\000\000\000\000\000\000\000\000\000\
    \055\000\000\000\000\000\055\000\043\000\000\000\078\000\078\000\
    \053\000\055\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\038\000\052\000\000\000\000\000\
    \048\000\054\000\055\000\042\000\057\000\255\255\255\255\054\000\
    \055\000\063\000\079\000\055\000\079\000\080\000\055\000\000\000\
    \000\000\055\000\063\000\079\000\000\000\079\000\080\000\055\000\
    \000\000\000\000\058\000\126\000\126\000\126\000\126\000\126\000\
    \126\000\126\000\126\000\000\000\057\000\000\000\000\000\054\000\
    \000\000\063\000\079\000\000\000\079\000\080\000\055\000\149\000\
    \000\000\000\000\063\000\079\000\000\000\079\000\080\000\055\000\
    \000\000\000\000\058\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\000\000\
    \000\000\000\000\032\000\000\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\046\000\120\000\
    \000\000\000\000\000\000\047\000\127\000\127\000\127\000\127\000\
    \127\000\127\000\127\000\127\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\255\255\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\000\000\
    \000\000\000\000\000\000\032\000\000\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\041\000\000\000\255\255\255\255\045\000\000\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\000\000\000\000\148\000\154\000\255\255\
    \255\255\000\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\255\255\050\000\153\000\000\000\
    \045\000\000\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\255\255\000\000\000\000\083\000\
    \000\000\085\000\085\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\048\000\048\000\000\000\051\000\069\000\084\000\069\000\
    \000\000\082\000\000\000\082\000\000\000\069\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \053\000\000\000\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\000\000\069\000\084\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\000\000\054\000\
    \000\000\255\255\000\000\000\000\255\255\000\000\080\000\000\000\
    \000\000\000\000\000\000\073\000\000\000\073\000\052\000\080\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\142\000\000\000\000\000\000\000\000\000\054\000\
    \000\000\000\000\000\000\140\000\141\000\000\000\080\000\140\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\059\000\080\000\
    \060\000\060\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\140\000\000\000\139\000\000\000\000\000\000\000\
    \000\000\060\000\060\000\060\000\060\000\060\000\060\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\000\000\000\000\000\000\144\000\000\000\000\000\000\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\000\000\000\000\
    \000\000\060\000\060\000\060\000\060\000\060\000\060\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\000\000\000\000\000\000\152\000\255\255\255\255\000\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\000\000\000\000\
    \062\000\000\000\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\000\000\000\000\000\000\000\000\000\000\063\000\000\000\
    \000\000\000\000\061\000\071\000\000\000\071\000\000\000\063\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\255\255\060\000\060\000\060\000\060\000\060\000\
    \060\000\000\000\000\000\000\000\000\000\000\000\063\000\000\000\
    \000\000\000\000\061\000\000\000\000\000\000\000\000\000\063\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\000\000\255\255\255\255\000\000\255\255\255\255\
    \000\000\065\000\065\000\065\000\065\000\065\000\065\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \064\000\000\000\000\000\000\000\142\000\145\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \255\255\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\000\000\000\000\000\000\
    \064\000\000\000\068\000\000\000\068\000\000\000\066\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\000\000\255\255\000\000\000\000\000\000\000\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\000\000\144\000\144\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\066\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\069\000\000\000\069\000\000\000\000\000\
    \000\000\000\000\000\000\069\000\000\000\069\000\000\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \000\000\000\000\000\000\069\000\000\000\069\000\000\000\000\000\
    \000\000\000\000\000\000\069\000\000\000\069\000\000\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\069\000\000\000\069\000\000\000\000\000\000\000\
    \000\000\000\000\069\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\069\000\000\000\069\000\000\000\000\000\077\000\
    \000\000\077\000\069\000\075\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\255\255\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\075\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \069\000\000\000\069\000\000\000\000\000\000\000\000\000\000\000\
    \069\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\069\000\000\000\069\000\
    \069\000\000\000\069\000\000\000\090\000\069\000\090\000\000\000\
    \069\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\085\000\085\000\069\000\000\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\000\000\069\000\
    \086\000\069\000\000\000\088\000\000\000\088\000\000\000\069\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\000\000\000\000\000\000\069\000\
    \086\000\069\000\000\000\000\000\000\000\000\000\069\000\069\000\
    \069\000\000\000\000\000\000\000\000\000\000\000\069\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\000\000\000\000\000\000\069\000\255\255\
    \069\000\000\000\255\255\000\000\000\000\069\000\069\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\089\000\089\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \142\000\000\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\000\000\069\000\000\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\069\000\093\000\
    \069\000\000\000\095\000\000\000\095\000\000\000\069\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\000\000\000\000\000\000\069\000\093\000\
    \069\000\000\000\144\000\000\000\000\000\069\000\069\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\094\000\094\000\
    \094\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\122\000\132\000\133\000\000\000\069\000\122\000\069\000\
    \000\000\000\000\000\000\000\000\000\000\069\000\000\000\123\000\
    \123\000\123\000\123\000\123\000\123\000\123\000\123\000\000\000\
    \000\000\132\000\000\000\000\000\000\000\000\000\122\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\131\000\131\000\000\000\000\000\000\000\000\000\124\000\
    \000\000\000\000\000\000\122\000\000\000\000\000\000\000\000\000\
    \122\000\122\000\000\000\000\000\000\000\122\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\122\000\000\000\000\000\
    \000\000\122\000\000\000\122\000\000\000\122\000\000\000\124\000\
    \125\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
    \125\000\125\000\000\000\000\000\000\000\130\000\000\000\000\000\
    \000\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
    \125\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
    \125\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \125\000\125\000\125\000\125\000\125\000\125\000\255\255\000\000\
    \000\000\125\000\125\000\125\000\125\000\125\000\125\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \125\000\125\000\125\000\125\000\125\000\125\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_check =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\003\000\003\000\003\000\000\000\
    \000\000\005\000\010\000\010\000\013\000\015\000\020\000\021\000\
    \022\000\023\000\025\000\027\000\024\000\028\000\029\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\036\000\023\000\024\000\024\000\035\000\036\000\057\000\
    \057\000\091\000\097\000\027\000\100\000\038\000\021\000\101\000\
    \038\000\038\000\030\000\029\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\102\000\104\000\
    \107\000\130\000\134\000\135\000\038\000\153\000\255\255\255\255\
    \255\255\030\000\055\000\118\000\255\255\255\255\255\255\255\255\
    \030\000\255\255\255\255\055\000\035\000\255\255\078\000\078\000\
    \031\000\030\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\038\000\027\000\255\255\255\255\
    \029\000\030\000\055\000\040\000\031\000\048\000\052\000\031\000\
    \030\000\063\000\078\000\055\000\079\000\080\000\031\000\255\255\
    \255\255\030\000\063\000\078\000\255\255\079\000\080\000\031\000\
    \255\255\255\255\031\000\123\000\123\000\123\000\123\000\123\000\
    \123\000\123\000\123\000\255\255\031\000\255\255\255\255\031\000\
    \255\255\063\000\078\000\255\255\079\000\080\000\031\000\146\000\
    \255\255\255\255\063\000\078\000\255\255\079\000\080\000\031\000\
    \255\255\255\255\031\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\255\255\255\255\
    \255\255\255\255\032\000\255\255\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\033\000\118\000\
    \255\255\255\255\255\255\033\000\126\000\126\000\126\000\126\000\
    \126\000\126\000\126\000\126\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\255\255\255\255\
    \255\255\027\000\255\255\255\255\029\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\255\255\
    \255\255\255\255\255\255\033\000\255\255\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\040\000\255\255\048\000\052\000\034\000\255\255\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\255\255\255\255\146\000\150\000\047\000\
    \049\000\255\255\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\047\000\049\000\150\000\255\255\
    \045\000\255\255\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\045\000\045\000\045\000\045\000\
    \045\000\045\000\045\000\045\000\046\000\255\255\255\255\053\000\
    \255\255\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\047\000\049\000\255\255\046\000\053\000\053\000\053\000\
    \255\255\054\000\255\255\054\000\255\255\053\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \056\000\255\255\056\000\056\000\056\000\056\000\056\000\056\000\
    \056\000\056\000\056\000\056\000\255\255\053\000\053\000\053\000\
    \255\255\255\255\255\255\255\255\255\255\053\000\255\255\056\000\
    \255\255\139\000\255\255\255\255\139\000\255\255\056\000\255\255\
    \255\255\255\255\255\255\061\000\255\255\061\000\046\000\056\000\
    \061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
    \061\000\061\000\139\000\255\255\255\255\255\255\255\255\056\000\
    \255\255\255\255\255\255\137\000\137\000\255\255\056\000\137\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\058\000\056\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\137\000\255\255\137\000\255\255\255\255\255\255\
    \255\255\058\000\058\000\058\000\058\000\058\000\058\000\059\000\
    \059\000\059\000\059\000\059\000\059\000\059\000\059\000\059\000\
    \059\000\255\255\255\255\255\255\139\000\255\255\255\255\255\255\
    \059\000\059\000\059\000\059\000\059\000\059\000\255\255\255\255\
    \255\255\058\000\058\000\058\000\058\000\058\000\058\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\255\255\255\255\255\255\150\000\047\000\049\000\255\255\
    \059\000\059\000\059\000\059\000\059\000\059\000\255\255\255\255\
    \060\000\255\255\060\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\060\000\060\000\060\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\060\000\060\000\060\000\060\000\060\000\
    \060\000\255\255\255\255\255\255\255\255\255\255\060\000\255\255\
    \255\255\255\255\060\000\064\000\255\255\064\000\255\255\060\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\046\000\060\000\060\000\060\000\060\000\060\000\
    \060\000\255\255\255\255\255\255\255\255\255\255\060\000\255\255\
    \255\255\255\255\060\000\255\255\255\255\255\255\255\255\060\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\255\255\143\000\144\000\255\255\143\000\144\000\
    \255\255\062\000\062\000\062\000\062\000\062\000\062\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \062\000\255\255\255\255\255\255\143\000\144\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \139\000\062\000\062\000\062\000\062\000\062\000\062\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\255\255\255\255\255\255\
    \062\000\255\255\066\000\255\255\066\000\255\255\065\000\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\255\255\137\000\255\255\255\255\255\255\255\255\065\000\
    \065\000\065\000\065\000\065\000\065\000\255\255\143\000\144\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\065\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\067\000\255\255\067\000\255\255\255\255\
    \255\255\255\255\255\255\067\000\255\255\070\000\255\255\070\000\
    \255\255\255\255\255\255\255\255\255\255\070\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \255\255\255\255\255\255\067\000\255\255\067\000\255\255\255\255\
    \255\255\255\255\255\255\067\000\255\255\070\000\255\255\070\000\
    \255\255\255\255\255\255\255\255\255\255\070\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\073\000\072\000\255\255\072\000\255\255\255\255\255\255\
    \255\255\255\255\072\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\074\000\074\000\074\000\074\000\
    \074\000\074\000\072\000\255\255\072\000\255\255\255\255\075\000\
    \255\255\075\000\072\000\074\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\074\000\074\000\074\000\074\000\
    \074\000\074\000\143\000\144\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\074\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \076\000\255\255\076\000\255\255\255\255\255\255\255\255\255\255\
    \076\000\081\000\081\000\081\000\081\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\081\000\255\255\081\000\
    \076\000\255\255\076\000\255\255\084\000\081\000\084\000\255\255\
    \076\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\085\000\085\000\085\000\085\000\085\000\
    \085\000\085\000\085\000\085\000\085\000\081\000\255\255\081\000\
    \255\255\255\255\255\255\255\255\255\255\081\000\255\255\085\000\
    \085\000\085\000\255\255\086\000\255\255\086\000\255\255\085\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\255\255\255\255\255\255\085\000\
    \085\000\085\000\255\255\255\255\255\255\255\255\087\000\085\000\
    \087\000\255\255\255\255\255\255\255\255\255\255\087\000\088\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\089\000\255\255\255\255\255\255\087\000\145\000\
    \087\000\255\255\145\000\255\255\255\255\089\000\087\000\089\000\
    \255\255\255\255\255\255\255\255\255\255\089\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \145\000\255\255\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\255\255\089\000\255\255\089\000\
    \255\255\255\255\255\255\255\255\255\255\089\000\092\000\092\000\
    \092\000\255\255\093\000\255\255\093\000\255\255\092\000\093\000\
    \093\000\093\000\093\000\093\000\093\000\093\000\093\000\093\000\
    \093\000\094\000\094\000\094\000\094\000\094\000\094\000\094\000\
    \094\000\094\000\094\000\255\255\255\255\255\255\092\000\092\000\
    \092\000\255\255\145\000\255\255\255\255\094\000\092\000\094\000\
    \255\255\255\255\255\255\255\255\255\255\094\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\121\000\128\000\128\000\255\255\094\000\121\000\094\000\
    \255\255\255\255\255\255\255\255\255\255\094\000\255\255\121\000\
    \121\000\121\000\121\000\121\000\121\000\121\000\121\000\255\255\
    \255\255\128\000\255\255\255\255\255\255\255\255\121\000\131\000\
    \131\000\131\000\131\000\131\000\131\000\131\000\131\000\131\000\
    \131\000\128\000\128\000\128\000\128\000\128\000\128\000\128\000\
    \128\000\128\000\128\000\255\255\255\255\255\255\255\255\121\000\
    \255\255\255\255\255\255\121\000\255\255\255\255\255\255\255\255\
    \121\000\121\000\255\255\255\255\255\255\121\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\121\000\255\255\255\255\
    \255\255\121\000\255\255\121\000\255\255\121\000\255\255\121\000\
    \124\000\124\000\124\000\124\000\124\000\124\000\124\000\124\000\
    \124\000\124\000\255\255\255\255\255\255\128\000\255\255\255\255\
    \255\255\124\000\124\000\124\000\124\000\124\000\124\000\125\000\
    \125\000\125\000\125\000\125\000\125\000\125\000\125\000\125\000\
    \125\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \125\000\125\000\125\000\125\000\125\000\125\000\145\000\255\255\
    \255\255\124\000\124\000\124\000\124\000\124\000\124\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \125\000\125\000\125\000\125\000\125\000\125\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\128\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    ";
  Lexing.lex_base_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\007\000\010\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_default_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\001\000\001\000\000\000\000\000\000\000\004\000\
    \004\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000";
  Lexing.lex_check_code =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\033\000\255\255\255\255\255\255\000\000\
    \033\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255";
  Lexing.lex_code =
   "\255\001\255\255\002\255\255\000\002\255\000\001\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 3 (-1); __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 348 "src/kernel_internals/parsing/logic_lexer.mll"
           ( token lexbuf )
# 971 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 349 "src/kernel_internals/parsing/logic_lexer.mll"
         ( Lexing.new_line lexbuf; token lexbuf )
# 976 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 350 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( Lexing.new_line lexbuf; token lexbuf )
# 981 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 351 "src/kernel_internals/parsing/logic_lexer.mll"
                     ( token lexbuf )
# 986 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 352 "src/kernel_internals/parsing/logic_lexer.mll"
         ( lex_error lexbuf "unexpected block-comment closing" )
# 991 "src/kernel_internals/parsing/logic_lexer.ml"

  | 5 ->
# 353 "src/kernel_internals/parsing/logic_lexer.mll"
         ( if !accept_c_comments_into_acsl_spec
           then comment lexbuf
           else lex_error lexbuf "unexpected block-comment opening"
         )
# 999 "src/kernel_internals/parsing/logic_lexer.ml"

  | 6 ->
# 358 "src/kernel_internals/parsing/logic_lexer.mll"
                       ( bs_identifier lexbuf )
# 1004 "src/kernel_internals/parsing/logic_lexer.ml"

  | 7 ->
# 359 "src/kernel_internals/parsing/logic_lexer.mll"
                        (
      let loc = Lexing.(lexeme_start_p lexbuf, lexeme_end_p lexbuf) in
      let cabsloc = Cil_datatype.Location.of_lexing_loc loc in
      let s = lexeme lexbuf in
      let curr_tok = identifier s cabsloc in
      if curr_tok = CHECK || curr_tok = ADMIT then begin
        let next_tok =
          token { lexbuf with refill_buff = lexbuf.refill_buff }
        in
        let (eat_next, tok) = hack_merge_tokens curr_tok next_tok in
        if eat_next then ignore (token lexbuf);
        tok
      end else curr_tok
    )
# 1022 "src/kernel_internals/parsing/logic_lexer.ml"

  | 8 ->
# 374 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1027 "src/kernel_internals/parsing/logic_lexer.ml"

  | 9 ->
# 375 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1032 "src/kernel_internals/parsing/logic_lexer.ml"

  | 10 ->
# 376 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1037 "src/kernel_internals/parsing/logic_lexer.ml"

  | 11 ->
# 377 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1042 "src/kernel_internals/parsing/logic_lexer.ml"

  | 12 ->
# 378 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( INT_CONSTANT (lexeme lexbuf) )
# 1047 "src/kernel_internals/parsing/logic_lexer.ml"

  | 13 ->
let
# 379 "src/kernel_internals/parsing/logic_lexer.mll"
                 prelude
# 1053 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 379 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                   content
# 1058 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 380 "src/kernel_internals/parsing/logic_lexer.mll"
      (
        let b = Buffer.create 5 in
        Buffer.add_string b prelude;
        let lbf = Lexing.from_string content in
        INT_CONSTANT (chr b lbf ^ "'")
      )
# 1067 "src/kernel_internals/parsing/logic_lexer.ml"

  | 14 ->
# 393 "src/kernel_internals/parsing/logic_lexer.mll"
      ( FLOAT_CONSTANT (lexeme lexbuf) )
# 1072 "src/kernel_internals/parsing/logic_lexer.ml"

  | 15 ->
let
# 396 "src/kernel_internals/parsing/logic_lexer.mll"
            n
# 1078 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -2) in
# 396 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( lexbuf.lex_curr_pos <- lexbuf.lex_curr_pos - 2;
                              INT_CONSTANT n )
# 1083 "src/kernel_internals/parsing/logic_lexer.ml"

  | 16 ->
let
# 399 "src/kernel_internals/parsing/logic_lexer.mll"
                prelude
# 1089 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 399 "src/kernel_internals/parsing/logic_lexer.mll"
                                                                content
# 1094 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 400 "src/kernel_internals/parsing/logic_lexer.mll"
      ( STRING_LITERAL (prelude.[0] = 'L',content) )
# 1098 "src/kernel_internals/parsing/logic_lexer.ml"

  | 17 ->
# 401 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( hash lexbuf )
# 1103 "src/kernel_internals/parsing/logic_lexer.ml"

  | 18 ->
# 402 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IMPLIES )
# 1108 "src/kernel_internals/parsing/logic_lexer.ml"

  | 19 ->
# 403 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( IFF )
# 1113 "src/kernel_internals/parsing/logic_lexer.ml"

  | 20 ->
# 404 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIMPLIES )
# 1118 "src/kernel_internals/parsing/logic_lexer.ml"

  | 21 ->
# 405 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( BIFF )
# 1123 "src/kernel_internals/parsing/logic_lexer.ml"

  | 22 ->
# 406 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AND )
# 1128 "src/kernel_internals/parsing/logic_lexer.ml"

  | 23 ->
# 407 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( OR )
# 1133 "src/kernel_internals/parsing/logic_lexer.ml"

  | 24 ->
# 408 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NOT )
# 1138 "src/kernel_internals/parsing/logic_lexer.ml"

  | 25 ->
# 409 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOLLAR )
# 1143 "src/kernel_internals/parsing/logic_lexer.ml"

  | 26 ->
# 410 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COMMA )
# 1148 "src/kernel_internals/parsing/logic_lexer.ml"

  | 27 ->
# 411 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( ARROW )
# 1153 "src/kernel_internals/parsing/logic_lexer.ml"

  | 28 ->
# 412 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Test state_stack; QUESTION )
# 1158 "src/kernel_internals/parsing/logic_lexer.ml"

  | 29 ->
# 413 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SEMICOLON )
# 1163 "src/kernel_internals/parsing/logic_lexer.ml"

  | 30 ->
# 414 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( match get_state() with
                                  Normal  -> COLON
                                | Test -> pop_state(); COLON2
                            )
# 1171 "src/kernel_internals/parsing/logic_lexer.ml"

  | 31 ->
# 418 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( COLONCOLON )
# 1176 "src/kernel_internals/parsing/logic_lexer.ml"

  | 32 ->
# 419 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOT )
# 1181 "src/kernel_internals/parsing/logic_lexer.ml"

  | 33 ->
# 420 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOT )
# 1186 "src/kernel_internals/parsing/logic_lexer.ml"

  | 34 ->
# 421 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( DOTDOTDOT )
# 1191 "src/kernel_internals/parsing/logic_lexer.ml"

  | 35 ->
# 422 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( MINUS )
# 1196 "src/kernel_internals/parsing/logic_lexer.ml"

  | 36 ->
# 423 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PLUS )
# 1201 "src/kernel_internals/parsing/logic_lexer.ml"

  | 37 ->
# 424 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STAR )
# 1206 "src/kernel_internals/parsing/logic_lexer.ml"

  | 38 ->
# 425 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( STARHAT )
# 1211 "src/kernel_internals/parsing/logic_lexer.ml"

  | 39 ->
# 426 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( AMP )
# 1216 "src/kernel_internals/parsing/logic_lexer.ml"

  | 40 ->
# 427 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HATHAT )
# 1221 "src/kernel_internals/parsing/logic_lexer.ml"

  | 41 ->
# 428 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( HAT )
# 1226 "src/kernel_internals/parsing/logic_lexer.ml"

  | 42 ->
# 429 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PIPE )
# 1231 "src/kernel_internals/parsing/logic_lexer.ml"

  | 43 ->
# 430 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( TILDE )
# 1236 "src/kernel_internals/parsing/logic_lexer.ml"

  | 44 ->
# 431 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( SLASH )
# 1241 "src/kernel_internals/parsing/logic_lexer.ml"

  | 45 ->
# 432 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( PERCENT )
# 1246 "src/kernel_internals/parsing/logic_lexer.ml"

  | 46 ->
# 433 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LT )
# 1251 "src/kernel_internals/parsing/logic_lexer.ml"

  | 47 ->
# 434 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GT )
# 1256 "src/kernel_internals/parsing/logic_lexer.ml"

  | 48 ->
# 435 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LE )
# 1261 "src/kernel_internals/parsing/logic_lexer.ml"

  | 49 ->
# 436 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GE )
# 1266 "src/kernel_internals/parsing/logic_lexer.ml"

  | 50 ->
# 437 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQ )
# 1271 "src/kernel_internals/parsing/logic_lexer.ml"

  | 51 ->
# 438 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EQUAL )
# 1276 "src/kernel_internals/parsing/logic_lexer.ml"

  | 52 ->
# 439 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( NE )
# 1281 "src/kernel_internals/parsing/logic_lexer.ml"

  | 53 ->
# 440 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LPAR )
# 1286 "src/kernel_internals/parsing/logic_lexer.ml"

  | 54 ->
# 441 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RPAR )
# 1291 "src/kernel_internals/parsing/logic_lexer.ml"

  | 55 ->
# 442 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LBRACE )
# 1296 "src/kernel_internals/parsing/logic_lexer.ml"

  | 56 ->
# 443 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RBRACE )
# 1301 "src/kernel_internals/parsing/logic_lexer.ml"

  | 57 ->
# 444 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUARE )
# 1306 "src/kernel_internals/parsing/logic_lexer.ml"

  | 58 ->
# 445 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUARE )
# 1311 "src/kernel_internals/parsing/logic_lexer.ml"

  | 59 ->
# 446 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( Stack.push Normal state_stack; LSQUAREPIPE )
# 1316 "src/kernel_internals/parsing/logic_lexer.ml"

  | 60 ->
# 447 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( pop_state(); RSQUAREPIPE )
# 1321 "src/kernel_internals/parsing/logic_lexer.ml"

  | 61 ->
# 448 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( LTLT )
# 1326 "src/kernel_internals/parsing/logic_lexer.ml"

  | 62 ->
# 449 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( GTGT )
# 1331 "src/kernel_internals/parsing/logic_lexer.ml"

  | 63 ->
let
# 450 "src/kernel_internals/parsing/logic_lexer.mll"
                 c
# 1337 "src/kernel_internals/parsing/logic_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 450 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( find_utf8 c )
# 1341 "src/kernel_internals/parsing/logic_lexer.ml"

  | 64 ->
# 451 "src/kernel_internals/parsing/logic_lexer.mll"
                            ( EOF )
# 1346 "src/kernel_internals/parsing/logic_lexer.ml"

  | 65 ->
# 452 "src/kernel_internals/parsing/logic_lexer.mll"
        ( lex_error lexbuf ("illegal character " ^ lexeme lexbuf) )
# 1351 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and chr buffer lexbuf =
   __ocaml_lex_chr_rec buffer lexbuf 118
and __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 456 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 2 (String.length s - 2) in
        let rec add_one_char s =
          let l = String.length s in
          if l = 0 then ()
          else
          let h = int_of_digit s.[0] in
          let c,s =
            if l = 1 then (h,"")
            else
              (16*h + int_of_digit s.[1],
               String.sub s 2 (String.length s - 2))
          in
          Buffer.add_char buffer (Char.chr c); add_one_char s
        in add_one_char real_s; chr buffer lexbuf
      )
# 1378 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 473 "src/kernel_internals/parsing/logic_lexer.mll"
      ( let s = lexeme lexbuf in
        let real_s = String.sub s 1 (String.length s - 1) in
        let rec value i s =
          if s = "" then i
          else value (8*i+int_of_digit s.[0])
            (String.sub s 1 (String.length s -1))
        in let c = value 0 real_s in
        Buffer.add_char buffer (Char.chr c); chr buffer lexbuf
      )
# 1391 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 483 "src/kernel_internals/parsing/logic_lexer.mll"
      ( Buffer.add_char buffer
          (match (lexeme lexbuf).[1] with
               'a' -> '\007'
             | 'b' -> '\b'
             | 'f' -> '\012'
             | 'n' -> '\n'
             | 'r' -> '\r'
             | 't' -> '\t'
             | 'v' -> '\011' (* no '\v' in OCaml 😞 *)
             | '\'' -> '\''
             | '"' -> '"'
             | '?' -> '?'
             | '\\' -> '\\'
             | _ -> (* escape regex does not allow anything else *) assert false
          ); chr buffer lexbuf)
# 1410 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 498 "src/kernel_internals/parsing/logic_lexer.mll"
        ( Buffer.contents buffer )
# 1415 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 499 "src/kernel_internals/parsing/logic_lexer.mll"
       ( Buffer.add_string buffer (lexeme lexbuf); chr buffer lexbuf )
# 1420 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_chr_rec buffer lexbuf __ocaml_lex_state

and hash lexbuf =
   __ocaml_lex_hash_rec lexbuf 128
and __ocaml_lex_hash_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 502 "src/kernel_internals/parsing/logic_lexer.mll"
        ( Lexing.new_line lexbuf; token lexbuf)
# 1432 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 503 "src/kernel_internals/parsing/logic_lexer.mll"
             ( hash lexbuf)
# 1437 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 504 "src/kernel_internals/parsing/logic_lexer.mll"
              ( (* We are seeing a line number. This is the number for the
                   * next line *)
                 let s = Lexing.lexeme lexbuf in
                 let lineno =
                   try
                     int_of_string s
                   with Failure _ ->
                     (* the int is too big. *)
                     Kernel.warning
                       ~source:(Cil_datatype.Position.of_lexing_pos lexbuf.lex_start_p)
                       "Bad line number in preprocessed file: %s"  s;
                     (-1)
                 in
                 update_line_pos lexbuf (lineno - 1);
                  (* A file name may follow *)
		  file lexbuf )
# 1457 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 520 "src/kernel_internals/parsing/logic_lexer.mll"
                ( hash lexbuf )
# 1462 "src/kernel_internals/parsing/logic_lexer.ml"

  | 4 ->
# 521 "src/kernel_internals/parsing/logic_lexer.mll"
            ( endline lexbuf)
# 1467 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_hash_rec lexbuf __ocaml_lex_state

and file lexbuf =
   __ocaml_lex_file_rec lexbuf 137
and __ocaml_lex_file_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 524 "src/kernel_internals/parsing/logic_lexer.mll"
                      ( Lexing.new_line lexbuf; token lexbuf)
# 1479 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 525 "src/kernel_internals/parsing/logic_lexer.mll"
                  ( file lexbuf)
# 1484 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 526 "src/kernel_internals/parsing/logic_lexer.mll"
                                        (
    let n = Lexing.lexeme lexbuf in
    let n1 = String.sub n 1
        ((String.length n) - 2) in
    let unescape = Str.regexp_string "\\\"" in
    let n1 = Str.global_replace unescape "\"" n1 in
    update_file_pos lexbuf n1;
    endline lexbuf
  )
# 1497 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 536 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1502 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_file_rec lexbuf __ocaml_lex_state

and endline lexbuf =
   __ocaml_lex_endline_rec lexbuf 146
and __ocaml_lex_endline_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 539 "src/kernel_internals/parsing/logic_lexer.mll"
                ( Lexing.new_line lexbuf; token lexbuf)
# 1514 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 540 "src/kernel_internals/parsing/logic_lexer.mll"
                                ( EOF )
# 1519 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 541 "src/kernel_internals/parsing/logic_lexer.mll"
      ( endline lexbuf)
# 1524 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_endline_rec lexbuf __ocaml_lex_state

and comment lexbuf =
   __ocaml_lex_comment_rec lexbuf 150
and __ocaml_lex_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 544 "src/kernel_internals/parsing/logic_lexer.mll"
         ( Lexing.new_line lexbuf; comment lexbuf)
# 1536 "src/kernel_internals/parsing/logic_lexer.ml"

  | 1 ->
# 545 "src/kernel_internals/parsing/logic_lexer.mll"
         ( token lexbuf)
# 1541 "src/kernel_internals/parsing/logic_lexer.ml"

  | 2 ->
# 546 "src/kernel_internals/parsing/logic_lexer.mll"
         ( lex_error lexbuf "non-terminating block-comment" )
# 1546 "src/kernel_internals/parsing/logic_lexer.ml"

  | 3 ->
# 547 "src/kernel_internals/parsing/logic_lexer.mll"
         ( comment lexbuf)
# 1551 "src/kernel_internals/parsing/logic_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_comment_rec lexbuf __ocaml_lex_state

;;

# 549 "src/kernel_internals/parsing/logic_lexer.mll"
 
  (* When Ocaml 4.11+ becomes mandatory, we can probably replace this with
     Lexing.set_position. *)
  let set_initial_position dest_lexbuf src_pos =
    dest_lexbuf.Lexing.lex_curr_p <- src_pos;
    dest_lexbuf.lex_abs_pos <- src_pos.pos_cnum

  let parse_from_position f (pos, s : Filepath.position * string) =
    let finally _ = Logic_utils.exit_kw_c_mode () in
    let output = Kernel.logwith finally ~wkey:Kernel.wkey_annot_error
    in
    let lb = from_string s in
    set_initial_position lb (Cil_datatype.Position.to_lexing_pos pos);
    try
      let res = f token lb in
      Some (Cil_datatype.Position.of_lexing_pos lb.Lexing.lex_curr_p, res)
    with
      | Failure s -> (* raised by the lexer itself, through [f] *)
          output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "lexing error: %s" s; None
      | Parsing.Parse_error ->
        output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "unexpected token '%s'" (Lexing.lexeme lb);
        None
      | Error (_, m) -> output ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "%s" m; None
      | Logic_utils.Not_well_formed (loc, m) ->
        output ~source:(fst loc) "%s" m;
        None
      | Log.FeatureRequest(source,_,msg) ->
        let source = Option.value ~default:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) source in
        output ~source "unimplemented ACSL feature: %s" msg; None
      | exn ->
        Kernel.fatal ~source:(Cil_datatype.Position.of_lexing_pos lb.lex_curr_p) "Unknown error (%s)"
          (Printexc.to_string exn)

  let lexpr = parse_from_position Logic_parser.lexpr_eof

  let annot = parse_from_position Logic_parser.annot

  let spec = parse_from_position Logic_parser.spec

  let ext_spec lexbuf = try
      accept_c_comments_into_acsl_spec := true ;
      let r = Logic_parser.ext_spec token lexbuf in
      accept_c_comments_into_acsl_spec := false ;
      r
    with exn ->
      accept_c_comments_into_acsl_spec := false ;
      raise exn

  type 'a parse = Filepath.position * string -> (Filepath.position * 'a) option

  let chr lexbuf =
    let buf = Buffer.create 16 in
    chr buf lexbuf

# 1613 "src/kernel_internals/parsing/logic_lexer.ml"
